@@ -30,12 +30,12 @@ import hashlib
 import os
 import re
 import sys
-from collections import Mapping
 from itertools import starmap
 from xml.dom.minidom import parseString
 
 import six
 from six.moves import zip_longest
+from six.moves.collections_abc import Mapping
 
 
 def deep_update(d, u):
@@ -314,11 +314,11 @@ def reraise_modify(caught_exc, append_msg, prepend=False):
 
 def remove_none(obj):
     if isinstance(obj, (list, tuple, set)):
-        l = type(obj)(remove_none(x) for x in obj if x)
+        lst = type(obj)(remove_none(x) for x in obj if x)
         try:
-            return [dict(t) for t in {tuple(sorted(d.items())) for d in l}]
+            return [dict(t) for t in {tuple(sorted(d.items())) for d in lst}]
         except (AttributeError, TypeError):
-            return l
+            return lst
     elif isinstance(obj, dict):
         return type(obj)((remove_none(k), remove_none(v))
                          for k, v in obj.items() if k is not None and v)
